@@ -14,7 +14,7 @@ def chat(value):
 		if("zackybot" in translated.text):
 			new_string = "Adım, kenu-ai. r4isy tarafından yazıldım."
 			return new_string
-		elif("Accobot" in translated.text):
+		elif("Acobot" in translated.text):
 			return "Sahibim namıdeğer r4isy."
 		else:
 			return translated.text
\ No newline at end of file
